ShelfUploadRequest<R> class
- Implemented types
Constructors
-
ShelfUploadRequest({required Request shelfRequest, ObjectData<
R> ? query, required Map<String, String> headers})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
-
query
→ ObjectData<
R> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shelfRequest → Request
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Stream< List< int> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromShelfRequest<
R, Res extends BaseResponse> (Request shelfRequest, HttpContract< R, Res> contract) → Future<ShelfUploadRequest< R> >