HttpContract<R, Res extends BaseResponse> class abstract

Implementers

Constructors

HttpContract({required String method, required String path, Schema<Map<String, dynamic>>? query, Schema? body, Schema<Map<String, dynamic>>? headers})

Properties

body → Schema?
final
hashCode int
The hash code for this object.
no setterinherited
headers → Schema<Map<String, dynamic>>?
final
method String
final
path String
final
query → Schema<Map<String, dynamic>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited