RawCommand<R> class

Inheritance

Constructors

RawCommand({String method = 'POST', required String path, required Schema<Map<String, dynamic>> body, Schema<Map<String, dynamic>>? query, Schema<Map<String, dynamic>>? headers})

Properties

body → Schema?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers → Schema<Map<String, dynamic>>?
finalinherited
method String
finalinherited
path String
finalinherited
query → Schema<Map<String, dynamic>>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited